@@ -4,9 +4,9 @@ from django.utils.translation import ugettext as _
 from django.template.loader import get_template
 from django.template import Context
 
-class BaseAdmin():
+class BaseAdmin(admin.ModelAdmin):
     def queryset(self, request):
-        qs = super(PhotoAdmin, self).queryset(request)
+        qs = super(BaseAdmin, self).queryset(request)
         if request.user.is_superuser:
             return qs
         return qs.filter(user=request.user)
@@ -15,7 +15,7 @@ class BaseAdmin():
         obj.user = request.user
         obj.save()
 
-class PhotoAdmin(admin.ModelAdmin, BaseAdmin):
+class PhotoAdmin(BaseAdmin):
     list_filter = ('display', 'timestamp_created', )
     list_display = ('name', 'display', 'timestamp_created', 'get_thumbnail', )
     date_hierarchy = 'timestamp_created'
@@ -31,7 +31,7 @@ class PhotoAdmin(admin.ModelAdmin, BaseAdmin):
 
 admin.site.register(Photo, PhotoAdmin)
 
-class AlbumAdmin(admin.ModelAdmin, BaseAdmin):
+class AlbumAdmin(BaseAdmin):
     list_filter = ('display', 'timestamp_created', )
     date_hierarchy = 'timestamp_created'
     description = _('Manage your galleries.')
